summaryrefslogtreecommitdiff
path: root/etc/themes/modus-operandi-theme.el
diff options
context:
space:
mode:
Diffstat (limited to 'etc/themes/modus-operandi-theme.el')
-rw-r--r--etc/themes/modus-operandi-theme.el20
1 files changed, 10 insertions, 10 deletions
diff --git a/etc/themes/modus-operandi-theme.el b/etc/themes/modus-operandi-theme.el
index a5e8fc701c4..646504636f0 100644
--- a/etc/themes/modus-operandi-theme.el
+++ b/etc/themes/modus-operandi-theme.el
@@ -1,10 +1,10 @@
;;; modus-operandi-theme.el --- Accessible light theme (WCAG AAA) -*- lexical-binding:t -*-
;; Copyright (C) 2019-2022 Free Software Foundation, Inc.
;; Author: Protesilaos Stavrou <info@protesilaos.com>
-;; URL: https://gitlab.com/protesilaos/modus-themes
-;; Version: 2.0.0
+;; URL: https://git.sr.ht/~protesilaos/modus-themes
+;; Version: 2.4.1
;; Package-Requires: ((emacs "27.1"))
;; Keywords: faces, theme, accessibility
@@ -56,17 +56,17 @@
(equal (file-name-directory load-file-name)
(expand-file-name "themes/" data-directory))
(require-theme 'modus-themes t))
- (require 'modus-themes)))
+ (require 'modus-themes))
-(deftheme modus-operandi
- "Accessible and customizable light theme (WCAG AAA standard).
+ (deftheme modus-operandi
+ "Elegant, highly legible and customizable light theme.
Conforms with the highest legibility standard for color contrast
between background and foreground in any given piece of text,
which corresponds to a minimum contrast in relative luminance of
-7:1.")
+7:1 (WCAG AAA standard).")
-(modus-themes-theme modus-operandi)
+ (modus-themes-theme modus-operandi)
-(provide-theme 'modus-operandi)
+ (provide-theme 'modus-operandi))
;;; modus-operandi-theme.el ends here
@@ -1,10 +1,10 @@
-;;; modus-operandi-theme.el --- Accessible light theme (WCAG AAA) -*- lexical-binding:t -*-
+;;; modus-operandi-theme.el --- Elegant, highly legible and customizable light theme -*- lexical-binding:t -*-
-;; Copyright (C) 2019-2022 Free Software Foundation, Inc.
+;; Copyright (C) 2019-2022 Free Software Foundation, Inc.
;; Author: Protesilaos Stavrou <info@protesilaos.com>